@@ -480,7 +480,9 @@ get_loadable_libraries(migratorContext *ctx)
 										"SELECT DISTINCT probin "
 										"FROM	pg_catalog.pg_proc "
 										"WHERE	prolang = 13 /* C */ AND "
-										"		probin IS NOT NULL");
+										"		probin IS NOT NULL AND "
+										"		oid >= "
+										STRINGIFY(FirstNormalObjectId) ";");
 		totaltups += PQntuples(ress[dbnum]);
 
 		PQfinish(conn);
