@@ -229,7 +229,7 @@ Options:\n\
  -P, --new-port=portnum          new cluster port number (default \"%d\")\n\
  \n\
  -u, --user=username             clusters superuser (default \"%s\")\n\
- -C, --check                     check clusters only, don't change any data\n\
+ -c, --check                     check clusters only, don't change any data\n\
  -g, --debug                     enable debugging\n\
  -G, --debugfile=DEBUGFILENAME   output debugging activity to file\n\
  -k, --link                      link instead of copying files to new cluster\n\
