@@ -22,7 +22,7 @@ static void uninstall_support_functions(migratorContext *ctx);
 static void generate_old_dump(migratorContext *ctx);
 static void split_old_dump(migratorContext *ctx);
 static void copy_clog_xlog_xid(migratorContext *ctx);
-static void	set_frozenxids(migratorContext *ctx);
+static void set_frozenxids(migratorContext *ctx);
 static void check_cluster_versions(migratorContext *ctx);
 static void check_cluster_compatibility(migratorContext *ctx);
 static void setup(migratorContext *ctx, char *argv0);
@@ -59,6 +59,8 @@ main(int argc, char **argv)
 	
 	get_pg_database_relfilenode(&ctx, CLUSTER_OLD);
 
+	get_autovacuum_freeze_max_age(&ctx, CLUSTER_OLD);
+
 	/* Extract a list of databases and tables from the old cluster */
 	get_db_and_rel_infos(&ctx, &ctx.old.dbarr, CLUSTER_OLD);
 
@@ -92,6 +94,9 @@ main(int argc, char **argv)
 			sequence_script_file_name =
 				v8_3_create_sequence_script(&ctx, CLUSTER_OLD);
 	}
+	if (GET_MAJOR_VERSION(ctx.old.pg_version) <= 804 &&
+		GET_MAJOR_VERSION(ctx.new.pg_version) >= 805)
+		v8_4_populate_pg_largeobject_metadata(&ctx, true, CLUSTER_OLD);
 
 	/* Looks okay so far.  Prepare the pg_dump output */
 	generate_old_dump(&ctx);
@@ -109,10 +114,16 @@ main(int argc, char **argv)
 
 	check_loadable_libraries(&ctx);
 
+	get_autovacuum_freeze_max_age(&ctx, CLUSTER_NEW);
+
 	stop_postmaster(&ctx, false, false);
 
 	check_locale_and_encoding(&ctx, &ctx.old.controldata, &ctx.new.controldata);
 
+	if (ctx.old.autovacuum_freeze_max_age > ctx.new.autovacuum_freeze_max_age)
+		pg_log(&ctx, PG_FATAL,
+			   "old cluster has a greater autovacuum_freeze_max_age than the new cluster\n");
+
 	if (ctx.transfer_mode == TRANSFER_MODE_LINK)
 		check_hard_link(&ctx);
 	
@@ -139,7 +150,7 @@ main(int argc, char **argv)
 	 * would cause us to lose the frozenids restored by the load.
 	 * We use --analyze so autovacuum doesn't update statistics later
 	 */
-	prep_status(&ctx, "Analyzing all rows on the new cluster");
+	prep_status(&ctx, "Analyzing all rows in the new cluster");
 	exec_prog(&ctx, true,
 			  SYSTEMQUOTE "\"%s/vacuumdb\" --port %d --all --analyze >> %s 2>&1" SYSTEMQUOTE,
 			  ctx.new.bindir, ctx.new.port, ctx.logfile);
@@ -182,7 +193,6 @@ main(int argc, char **argv)
 	
 	/*
 	 *	Rename all tablespace paths to .old so we can copy them later.
-	 *	DESTRUCTIVE of old cluster
 	 */
 	prep_status(&ctx, "Renaming tablespaces to *.old");
 	rename_tablespaces(&ctx);
@@ -195,13 +205,18 @@ main(int argc, char **argv)
 	/* -- NEW -- */
 	start_postmaster(&ctx, CLUSTER_NEW, false);
 
+	/*
+	 *	We check autovacuum_freeze_max_age above to make sure autovacuum does
+	 *	not launch here and delete clog files, before the frozen xids are set.
+	 */
+
 	set_frozenxids(&ctx);
 
 	/*
 	 * We have to create the databases first so we can create the
 	 * toast table placeholder relfiles.
 	 */
-	prep_status(&ctx, "Creating databases in new cluster");
+	prep_status(&ctx, "Creating databases in the new cluster");
 	exec_prog(&ctx, true,
 			  SYSTEMQUOTE "\"%s/%s\" --set ON_ERROR_STOP=on --port %d "
 			  "-f \"%s/%s\" --dbname template1 >> \"%s\"" SYSTEMQUOTE,
@@ -294,6 +309,14 @@ main(int argc, char **argv)
 		v8_3_invalidate_bpchar_pattern_ops_indexes(&ctx, false, CLUSTER_NEW);
 		stop_postmaster(&ctx, false, true);
 	}
+
+	if (GET_MAJOR_VERSION(ctx.old.pg_version) <= 804 &&
+		GET_MAJOR_VERSION(ctx.new.pg_version) >= 805)
+	{
+		start_postmaster(&ctx, CLUSTER_NEW, true);
+		v8_4_populate_pg_largeobject_metadata(&ctx, false, CLUSTER_NEW);
+		stop_postmaster(&ctx, false, true);
+	}
 	
 	pg_log(&ctx, PG_REPORT, "\n*Upgrade complete*\n");
 
@@ -336,8 +359,8 @@ generate_old_dump(migratorContext *ctx)
  *	split_old_dump
  *
  *	This function splits pg_dumpall output into global values and
- *	database creation, and per-db scemas.  This allows us to create
- *	the toast place holders between retoring these two parts of the
+ *	database creation, and per-db schemas.  This allows us to create
+ *	the toast place holders between restoring these two parts of the
  *	dump.  We split on the first "\connect " after a CREATE ROLE
  *	username match;  this is where the per-db restore starts.
  *	
@@ -416,7 +439,7 @@ copy_clog_xlog_xid(migratorContext *ctx)
 	char		new_clog_path[MAXPGPATH];
 
 	/* copy old commit logs to new data dir */
-	prep_status(ctx, "Deleting old commit clogs");
+	prep_status(ctx, "Deleting new commit clogs");
 
 	snprintf(old_clog_path, sizeof(old_clog_path), "%s/pg_clog", ctx->old.pgdata);
 	snprintf(new_clog_path, sizeof(new_clog_path), "%s/pg_clog", ctx->new.pgdata);
@@ -424,7 +447,7 @@ copy_clog_xlog_xid(migratorContext *ctx)
 		pg_log(ctx, PG_FATAL, "Unable to delete directory %s\n", new_clog_path);
 	check_ok(ctx);
 
-	prep_status(ctx, "Copying commit clogs");
+	prep_status(ctx, "Copying old commit clogs to new server");
 	/* libpgport's copydir() doesn't work in FRONTEND code */
 #ifndef WIN32
 	exec_prog(ctx, true, SYSTEMQUOTE "%s \"%s\" \"%s\"" SYSTEMQUOTE,
@@ -486,8 +509,8 @@ static void	set_frozenxids(migratorContext *ctx)
 							"SELECT	datname "
 							"FROM	pg_catalog.pg_database "
 							"WHERE	datname != 'template0'");
-	/* free dbres below */
 
+	/* free dbres below */
 	PQfinish(conn);
 	
 	ntups = PQntuples(dbres);
