@@ -2,7 +2,7 @@
  *	pg_migrator.h
  */
 
-#define	PG_MIGRATOR_VERSION	"8.4.5"
+#define	PG_MIGRATOR_VERSION	"8.4.6"
 
 #include "postgres.h"
 
@@ -209,6 +209,7 @@ typedef struct
 	char	   *pg_version_str;	/* string PG_VERSION of cluster */
 	Oid			pg_database_oid;		/* OID of pg_database relation */
 	char	   *libpath;	/* pathname for cluster's pkglibdir */
+	uint32		autovacuum_freeze_max_age; /* must match old/new server */
 	/* EDB AS is PG 8.2 with 8.3 enhancements backpatched. */
 	bool		is_edb_as;	/* EnterpriseDB's Postgres Plus Advanced Server? */
 } ClusterInfo;
@@ -362,6 +363,7 @@ void 		start_postmaster(migratorContext *ctx, Cluster whichCluster, bool quiet);
 void		stop_postmaster(migratorContext *ctx, bool fast, bool quiet);
 uint32		get_postgres_version(migratorContext *ctx, char **verstr,
 								 Cluster whichCluster);
+void		get_autovacuum_freeze_max_age(migratorContext *ctx, Cluster whichCluster);
 void		check_for_libpq_envvars(migratorContext *ctx);
 
 
@@ -395,6 +397,8 @@ void		v8_3_invalidate_hash_gin_indexes(migratorContext *ctx,
 							bool check_mode, Cluster whichCluster);
 void		v8_3_invalidate_bpchar_pattern_ops_indexes(migratorContext *ctx,
 							bool check_mode, Cluster whichCluster);
+void		v8_4_populate_pg_largeobject_metadata(migratorContext *ctx,
+							bool check_mode, Cluster whichCluster);
 char 		*v8_3_create_sequence_script(migratorContext *ctx,
 							Cluster whichCluster);
 void		check_for_composite_types(migratorContext *ctx,
